/*
SOLUTION WITH NUMBER THEORY - FAST MODPOW and EULER THEOREM

We must solve the system
x === m1 mod p1
x === m2 mod p2

The solution is mod p1*p2

x = q1 p1 + m1 = q2 p2 + m2

q1 p1 - q2 p2 = m2 - m1 ===

q1 p1 === rr mod p2

q1 === rr * p1^ mod p2

So we must write solver of Ax + By = c

By === c mod A

y === c B^(-1) mod A

We must find the inverse element of B mod A. We know that (B, A) = 1. We use 
Euler Theorem: (We can )
  B^phi(A) === 1 mod A
  B^(-1) === B^(phi(A) - 1)
  
  We know that A is prime, so phi(A) = A - 1. 
  We must make fast modpow
  
  A^P mod M
  P = 101010101;(2)
  A^(2^0 + 2^2 + 2^4)
*/ 
#include <iostream>
#include <stdlib.h>

#define MAXN 16
using namespace std;
#define num long long int

num modpow(num a, num p, num m){
  num res = 1, A = a; //a^2^0
  if(p == 0) return 1;
  while(p){
	//cout << "P:" << p << " R:" << res << " A:" << A <<endl;
    if(p % 2){res *= A; res = res % m;}
    A = A * A;
	A = A % m;
	p = p >> 1;
  }
  return res;
}

num inv(num a, num m){
  //finds the inverse of a mod m, m must be prime, (m, a) = 1
  if(m == 2) return 1;
  return modpow(a, m - 2, m);
}

num solve(num p1, num p2, num r1, num r2){
  //p2 must be prime
  num q1, rr = r2 - r1, pi1;
  while(rr < 0)rr += p2;
  //if(rr < 0) rr += p2;
  //if(rr >= p2) rr -= p2;
  while(rr >= p2) rr -= p2;
  if(rr == 0) return 0;
  
  pi1 = inv(p1, p2);
  q1 = rr * pi1;
  q1 = q1 % p2;
  //cout << "RR:" << rr << " IN:" << pi1 << " Q1: "<< q1 << endl;
  return (q1*p1 + r1) % (p1 * p2);
  
  //p1 q1 + r1 = p2 q2 + r2
  //p1 q1 === r2 - r1 mod p2
  //p1 q1 === rr
  //q1 === rr p1^(-1)	
}

int main(){
  int i, n;
  num p[MAXN], r[MAXN], mod, res;
  //cout << solve(2, 3, 0, 1)<<endl;
  cin >> n;
  for(i = 0; i < n; i ++)
    cin >> p[i];
  for(i = 0; i < n; i ++)
    cin >> r[i];
  //on every iteration
  mod = p[0];
  res = r[0];
  for(i = 1; i < n; i++){
    res = solve(mod, p[i], res, r[i]);
	mod *= p[i];		
  }
  if(res == 0){cout << mod << endl; return 0;}
  cout << res << endl;
  //system("pause");
  return 0;
}
